
import json
import os

from braket.aws import AwsDevice
from braket.circuits import Circuit
from braket.jobs import save_job_result
from braket.tracking import Tracker


def main():
    """
    Example Hybrid Job File
    """
    t = Tracker().start()

    device_arn = os.environ["AMZN_BRAKET_DEVICE_ARN"]
    # Initialise device
    device = AwsDevice(device_arn)
    print(f"Using device {device}")

    hyperparams = load_hyperparameters()
    print("Hyperparameters are:", hyperparams)

    shots = int(hyperparams.get("shots"))
    num_iter = int(hyperparams.get("num_iter"))

    counts = []
    bell = Circuit().h(0).cnot(0, 1)
    for count in range(num_iter):
        task = device.run(bell, shots=shots)
        print(task.result().measurement_counts)
        counts.append(task.result().measurement_counts)

    # return results as strings
    save_job_result(
        {
            "counts": json.dumps(counts),
            "task summary": t.quantum_tasks_statistics(),
            "estimated cost": t.qpu_tasks_cost() + t.simulator_tasks_cost()
        }
    )


def load_hyperparameters():
    """Load the Hybrid Job hyperparameters"""
    hp_file = os.environ["AMZN_BRAKET_HP_FILE"]
    with open(hp_file) as f:
        hyperparams = json.load(f)
    return hyperparams
